
// INPUT 
// 1 - GDP_by_Industry.xlsx (Excel file with industry quarterly data from:
//     https://apps.bea.gov/iTable/iTable.cfm?reqid=150&step=3&isuri=1&table_list=6009&categories=io
//     and with additional macro variables taken from Haver Analytics
// 2 - bea66_employment_quarterly.dta (created in run_employment_bls.do)

// OUTPUT
// 1 - stata_to_excel.xls
// 2 - five *eps and *pdf files with data charts

cls
set scheme s1color


clear
cd N:\Reallocation\Data

import excel "GDP_by_Industry.xlsx", ///
sheet("RGOBI") firstrow clear

preserve
drop Date
describe, replace clear
list
rename position BEA_line
save temp_industry_labels.dta, replace
restore


global i = 1
foreach var of varlist Allindustries-CT {
rename `var' vv$i
global i = $i+1
}
reshape long vv, i(Date) j(BEA_line)
rename vv output
replace output = output/1000
save temp_data_rgobi, replace








import excel "N:\inflation\Industry_Matteo\GrossOutput_forstata2.xlsx", ///
sheet("RGOBI") firstrow clear
global i = 1
foreach var of varlist Allindustries-CT {
rename `var' vv$i
global i = $i+1
}
reshape long vv, i(Date) j(BEA_line)
rename vv outputold
replace outputold = output/1000
save temp_data_rgobiold, replace




merge m:m Date BEA_line using "temp_data_rgobi.dta"
drop _merge

merge m:1 BEA_line using "temp_industry_labels.dta"
drop _merge format name type isnumer format vallab

label var output "Real Gross Output 2012$bn Dec12"
label var outputold "Real Gross Output 2012$bn Sept12"
label var BEA_line "Industry Numeric Order in BEA Tables"
rename Date date

gen Q = substr(date,6,1)
gen year = substr(date,1,4)
destring Q year, replace
gen M = Q*3
gen edate = mdy(M,1,year)
gen qdate = qofd(edate)
drop Q M edate
format qdate %tq
rename qdate quarter

label var quarter "Quarter"
label var year "Year"





foreach v of var * { 
         local l`v' : variable label `v' 
		 if `"`l`v''"' == "" { 
			local l`v' "`v'" 
		 } 
} 
 
collapse ///
(firstnm) varlab ///
(mean) output outputold, by(quarter BEA_line)

foreach v of var * {
	label var `v' "`l`v''"
}

replace varlab="State and local: General Government" if BEA_line==96
replace varlab="State and local: Government Enterprises" if BEA_line==97

gen varlab_original = varlab

replace varlab = strtrim(varlab)
tostring BEA_line, gen(BEA_line_string)

gen varlab_small = substr(varlab,1,18) + "-" + BEA_line_string
gen varlab_small_nonum = substr(varlab,1,18) 

label var varlab_original "Original Industry Label"
label var varlab "Trimmed Original Industry Label"
label var varlab_small "Industry Label String with BEA Line #"
label var varlab_small_nonum "Industry Label String without BEA Line #"

encode varlab_small, gen(varlabi)

xtset varlabi quarter
sort varlabi quarter





//--------------------------------------------
// Isolate the 66 BEA Industries
//--------------------------------------------

gen keycat66 = 0
label var keycat66 "0/1 if Industry is at highest level of disaggregation in BEA GDP Industry Tables"

// Broad categories
replace keycat66 = 1 if BEA_line==4
replace keycat66 = 1 if BEA_line==5
replace keycat66 = 1 if BEA_line==7
replace keycat66 = 1 if BEA_line==8
replace keycat66 = 1 if BEA_line==9
replace keycat66 = 1 if BEA_line==10
replace keycat66 = 1 if BEA_line==11
replace keycat66 = 1 if BEA_line>=14 & BEA_line<=24
replace keycat66 = 1 if BEA_line>=26 & BEA_line<=33
replace keycat66 = 1 if BEA_line==34
replace keycat66 = 1 if BEA_line>=36 & BEA_line<=39
replace keycat66 = 1 if BEA_line>=41 & BEA_line<=48
replace keycat66 = 1 if BEA_line>=50 & BEA_line<=53
replace keycat66 = 1 if BEA_line>=56 & BEA_line<=59
replace keycat66 = 1 if BEA_line>=62 & BEA_line<=64
replace keycat66 = 1 if BEA_line>=67 & BEA_line<=69
replace keycat66 = 1 if BEA_line==70
replace keycat66 = 1 if BEA_line>=72 & BEA_line<=73
replace keycat66 = 1 if BEA_line==75
replace keycat66 = 1 if BEA_line>=77 & BEA_line<=80
replace keycat66 = 1 if BEA_line>=83 & BEA_line<=84
replace keycat66 = 1 if BEA_line>=86 & BEA_line<=87
replace keycat66 = 1 if BEA_line==88

egen totoutput = sum(output) if keycat66==1 & output~=., by(quarter)
gen share = output/totoutput*100 if keycat66==1
label var totoutput "Aggregate Real Gross Output by quarter"
label var share "Industry-66 Share of Real Gross Output by quarter"

sort BEA_line
tabulate varlab_original, summarize(keycat66)
tabulate varlab_small if keycat66==1, summarize(share)

gen BEAName = varlab_original if keycat66==1
label var BEAName "Original Industry Label (66 Industries Only)"

sencode BEAName if keycat66==1, gen(BEAnumber_) gsort(varlabi)
gen BEA66 = BEAnumber_
drop BEAnumber_
sort BEA66
order BEA66 BEAName BEA_line

label var BEA66 "Numeric Value of 66 Industries sorted by original alph.name"


xtline output outputold if keycat66==1 & BEA_line<=22 & tin(2016q1,2022q4), ///
byopts(rescale) ylabel(, axis(1) angle(horizontal)) ///
tlabel(2017q1 2019q4 2022q1) ///








/// LIST AS PER BEA TABLES
/*
1	    Gross domestic product
2	Private industries
3	  Agriculture, forestry, fishing, and hunting
4	    Farms
5	    Forestry, fishing, and related activities
6	  Mining
7	    Oil and gas extraction
8	    Mining, except oil and gas
9	    Support activities for mining
10	  Utilities
11	  Construction
12	  Manufacturing
13	    Durable goods
14	      Wood products
15	      Nonmetallic mineral products
16	      Primary metals
17	      Fabricated metal products
18	      Machinery
19	      Computer and electronic products
20	      Electrical equipment, appliances, and components
21	      Motor vehicles, bodies and trailers, and parts
22	      Other transportation equipment
23	      Furniture and related products
24	      Miscellaneous manufacturing
25	    Nondurable goods
26	      Food and beverage and tobacco products
27	      Textile mills and textile product mills
28	      Apparel and leather and allied products
29	      Paper products
30	      Printing and related support activities
31	      Petroleum and coal products
32	      Chemical products
33	      Plastics and rubber products
34	  Wholesale trade
35	  Retail trade
36	    Motor vehicle and parts dealers
37	    Food and beverage stores
38	    General merchandise stores
39	    Other retail
40	  Transportation and warehousing
41	    Air transportation
42	    Rail transportation
43	    Water transportation
44	    Truck transportation
45	    Transit and ground passenger transportation
46	    Pipeline transportation
47	    Other transportation and support activities
48	    Warehousing and storage
49	  Information
50	    Publishing industries, except internet (includes software)
51	    Motion picture and sound recording industries
52	    Broadcasting and telecommunications
53	    Data processing, internet publishing, and other information services
54	  Finance, insurance, real estate, rental, and leasing
55	    Finance and insurance
56	      Federal Reserve banks, credit intermediation, and related activities
57	      Securities, commodity contracts, and investments
58	      Insurance carriers and related activities
59	      Funds, trusts, and other financial vehicles
60	    Real estate and rental and leasing
61	      Real estate
62	        Housing
63	        Other real estate
64	      Rental and leasing services and lessors of intangible assets
65	  Professional and business services
66	    Professional, scientific, and technical services
67	      Legal services
68	      Computer systems design and related services
69	      Miscellaneous professional, scientific, and technical services
70	    Management of companies and enterprises
71	    Administrative and waste management services
72	      Administrative and support services
73	      Waste management and remediation services
74	  Educational services, health care, and social assistance
75	    Educational services
76	    Health care and social assistance
77	      Ambulatory health care services
78	      Hospitals
79	      Nursing and residential care facilities
80	      Social assistance
81	  Arts, entertainment, recreation, accommodation, and food services
82	    Arts, entertainment, and recreation
83	      Performing arts, spectator sports, museums, and related activities
84	      Amusements, gambling, and recreation industries
85	    Accommodation and food services
86	      Accommodation
87	      Food services and drinking places
88	  Other services, except government
89	Government
90	  Federal
91	    General government
92	      National defense
93	      Nondefense
94	    Government enterprises
95	  State and local
96	    General government
97	    Government enterprises
98	  Not allocated by industry\1\
	  Addenda:
99	      Private goods-producing industries\2\
100	      Private services-producing industries\3\
101	      Information-communications-technology-producing industries\ 4\

*/

