
// INPUT 
// 1 - GDP_by_Industry.xlsx (Excel file with industry quarterly data from:
//     https://apps.bea.gov/iTable/iTable.cfm?reqid=150&step=3&isuri=1&table_list=6009&categories=io
//     and with additional macro variables taken from Haver Analytics
// 2 - bea66_employment_quarterly.dta (created in run_employment_bls.do)
// 3 - Consumption_monthly.csv (monthly consumption data created in run_GDP_by_Industry_R.R)


// OUTPUT
// 1 - stata_to_excel.xls
// 2 - *pdf files with data charts

cls
set scheme s1color


clear


global download_data = 0
global compare_with_bls_tfp = 0  // Set to 1 to compare with BLS productivity Data




if $download_data == 1 {



import excel "GDP_by_Industry.xlsx", sheet("PCE_HAVER") firstrow clear
gen Q = substr(Date,6,1)
gen year = substr(Date,1,4)
destring Q year, replace
gen M = Q*3
gen edate = mdy(M,1,year)
gen quarter = qofd(edate)
drop Q M edate
format quarter %tq

// This one assigns labels
local i=1
foreach vars of varlist C-XSH {
local label = Labels[`i']
label var `vars' "`label'"
local i=`i'+1
}

save tfile_macro_data_haver, replace


import excel "GDP_by_Industry.xlsx", ///
sheet("CTQI") firstrow clear

preserve
drop Date
describe, replace clear
list
rename position BEA_line
save temp_industry_labels.dta, replace
restore

global i = 1
foreach var of varlist Allindustries-CT {
rename `var' vv$i
global i = $i+1
}
reshape long vv, i(Date) j(BEA_line)
rename vv quantity
save temp_data_ctqi, replace




import excel "GDP_by_Industry.xlsx", ///
sheet("CTPI") firstrow clear
global i = 1
foreach var of varlist Allindustries-CT {
rename `var' vv$i
global i = $i+1
}
reshape long vv, i(Date) j(BEA_line)
rename vv price
save temp_data_ctpi, replace




import excel "GDP_by_Industry.xlsx", ///
sheet("RGOBI") firstrow clear
global i = 1
foreach var of varlist Allindustries-CT {
rename `var' vv$i
global i = $i+1
}
reshape long vv, i(Date) j(BEA_line)
rename vv output
save temp_data_rgobi, replace



import excel "GDP_by_Industry.xlsx", ///
sheet("GOBI") firstrow clear
global i = 1
foreach var of varlist Allindustries-CT {
rename `var' vv$i
global i = $i+1
}
reshape long vv, i(Date) j(BEA_line)
rename vv nominaloutput
replace nominaloutput = nominaloutput/1000
save temp_data_gobi, replace











import excel "GDP_by_Industry.xlsx", ///
sheet("RVABI") firstrow clear
global i = 1
foreach var of varlist Grossdomesticproduct-CT {
rename `var' vv$i
global i = $i+1
}
reshape long vv, i(Date) j(BEA_line)
rename vv rva
save temp_data_rvabi, replace



import excel "GDP_by_Industry.xlsx", ///
sheet("RIBI") firstrow clear
global i = 1
foreach var of varlist Allindustries-CT {
rename `var' vv$i
global i = $i+1
}
reshape long vv, i(Date) j(BEA_line)
rename vv ri
save temp_data_ribi, replace







merge m:m Date BEA_line using "temp_data_rvabi.dta"
drop _merge

merge m:m Date BEA_line using "temp_data_ctpi.dta"
drop _merge

merge m:m Date BEA_line using "temp_data_ctqi.dta"
drop _merge

merge m:m Date BEA_line using "temp_data_rgobi.dta"
drop _merge

merge m:m Date BEA_line using "temp_data_gobi.dta"
drop _merge

merge m:1 BEA_line using "temp_industry_labels.dta"
drop _merge format name type isnumer format vallab

label var nominaloutput "Gross Output by Industry, $mil"
label var output "Real Gross Output by Industry, 2012$mil"
label var price "Price Index by Industry (BEA), 2012=100"
label var quantity "Quantity Index by Industry (BEA)"
label var rva "Real Value Added by Industry (BEA), 2012$mil"
label var ri "Real Intermediates by Industry (BEA), 2012$mil"
label var BEA_line "Industry Numeric Order in BEA Tables"
rename Date date

gen Q = substr(date,6,1)
gen year = substr(date,1,4)
destring Q year, replace
gen M = Q*3
gen edate = mdy(M,1,year)
gen qdate = qofd(edate)
drop Q M edate
format qdate %tq
rename qdate quarter

label var quarter "Quarter"
label var year "Year"





erase temp_data_ctpi.dta
erase temp_data_ctqi.dta
erase temp_data_rgobi.dta
erase temp_data_gobi.dta
erase temp_data_ribi.dta
erase temp_data_rvabi.dta
erase temp_industry_labels.dta


foreach v of var * { 
         local l`v' : variable label `v' 
		 if `"`l`v''"' == "" { 
			local l`v' "`v'" 
		 } 
} 
 
collapse ///
(firstnm) varlab ///
(mean) price quantity output nominaloutput rva ri, by(quarter BEA_line)

foreach v of var * {
	label var `v' "`l`v''"
}

replace varlab="State and local: General Government" if BEA_line==96
replace varlab="State and local: Government Enterprises" if BEA_line==97

gen varlab_original = varlab

replace varlab = strtrim(varlab)
tostring BEA_line, gen(BEA_line_string)

gen varlab_small = substr(varlab,1,18) + "-" + BEA_line_string
gen varlab_small_nonum = substr(varlab,1,18) 
encode varlab, gen(varlabi)

label var varlab_original "Original Industry Label"
label var varlab "Trimmed Original Industry Label"
label var varlab_small "Industry Label String with BEA Line #"
label var varlab_small_nonum "Industry Label String without BEA Line #"

xtset varlabi quarter
sort varlabi quarter

merge m:1 quarter using tfile_macro_data_haver.dta
drop _merge

save tfile_industry_all_measures.dta, replace

}




use tfile_industry_all_measures.dta, clear




//--------------------------------------------
// Isolate the 66 and 14 BEA Industries
//--------------------------------------------

gen keycat66 = 0
label var keycat66 "0/1 if Industry is at highest level of disaggregation in BEA GDP Industry Tables"

// Broad categories
replace keycat66 = 1 if BEA_line==4
replace keycat66 = 1 if BEA_line==5
replace keycat66 = 1 if BEA_line==7
replace keycat66 = 1 if BEA_line==8
replace keycat66 = 1 if BEA_line==9
replace keycat66 = 1 if BEA_line==10
replace keycat66 = 1 if BEA_line==11
replace keycat66 = 1 if BEA_line>=14 & BEA_line<=24
replace keycat66 = 1 if BEA_line>=26 & BEA_line<=33
replace keycat66 = 1 if BEA_line==34
replace keycat66 = 1 if BEA_line>=36 & BEA_line<=39
replace keycat66 = 1 if BEA_line>=41 & BEA_line<=48
replace keycat66 = 1 if BEA_line>=50 & BEA_line<=53
replace keycat66 = 1 if BEA_line>=56 & BEA_line<=59
replace keycat66 = 1 if BEA_line>=62 & BEA_line<=64
replace keycat66 = 1 if BEA_line>=67 & BEA_line<=69
replace keycat66 = 1 if BEA_line==70
replace keycat66 = 1 if BEA_line>=72 & BEA_line<=73
replace keycat66 = 1 if BEA_line==75
replace keycat66 = 1 if BEA_line>=77 & BEA_line<=80
replace keycat66 = 1 if BEA_line>=83 & BEA_line<=84
replace keycat66 = 1 if BEA_line>=86 & BEA_line<=87
replace keycat66 = 1 if BEA_line==88

egen totoutput = sum(output) if keycat66==1 & output~=., by(quarter)
gen share = output/totoutput*100 if keycat66==1 & output~=.
label var totoutput "Aggregate Real Gross Output by quarter"
label var share "Industry-66 Share of Real Gross Output by quarter"

sort BEA_line
tabulate varlab_original, summarize(keycat66)
tabulate varlab_small if keycat66==1, summarize(share)

gen BEAName = varlab_original if keycat66==1
label var BEAName "Original Industry Label (66 Industries Only)"

sencode BEAName if keycat66==1, gen(BEAnumber_) gsort(varlabi)
gen BEA66 = BEAnumber_
drop BEAnumber_
sort BEA66
order BEA66 BEAName  BEA_line

label var BEA66 "Numeric Value of 66 Industries sorted by original alph.name"

gen secbea14 = .
label var secbea14 "Numeric Order of 14 Industries sorted by BEA line"
replace secbea14 = 1 if BEA_line>=4  & BEA_line<=5
replace secbea14 = 2 if BEA_line>=7  & BEA_line<=9
replace secbea14 = 3 if BEA_line>=10 & BEA_line<=10
replace secbea14 = 4 if BEA_line>=11 & BEA_line<=11
replace secbea14 = 5 if BEA_line>=14 & BEA_line<=33
replace secbea14 = 6 if BEA_line>=34 & BEA_line<=34
replace secbea14 = 7 if BEA_line>=36 & BEA_line<=39
replace secbea14 = 8 if BEA_line>=41 & BEA_line<=48
replace secbea14 = 9 if BEA_line>=50 & BEA_line<=53
replace secbea14 = 10 if BEA_line>=56 & BEA_line<=64
replace secbea14 = 11 if BEA_line>=67 & BEA_line<=73
replace secbea14 = 12 if BEA_line>=75 & BEA_line<=80
replace secbea14 = 13 if BEA_line>=83 & BEA_line<=87
replace secbea14 = 14 if BEA_line>=88 & BEA_line<=88
replace secbea14 = . if keycat66~=1

gen BEA14Name = ""
label var BEA14Name "Short Label for 14 BEA Industries"
replace BEA14Name = "Agr" if secbea14==1
replace BEA14Name = "Mine" if secbea14==2
replace BEA14Name = "Util." if secbea14==3
replace BEA14Name = "Constr." if secbea14==4
replace BEA14Name = "Manuf." if secbea14==5
replace BEA14Name = "Whlsl" if secbea14==6
replace BEA14Name = "Retail" if secbea14==7
replace BEA14Name = "Trnsp." if secbea14==8
replace BEA14Name = "IT" if secbea14==9
replace BEA14Name = "FIRE" if secbea14==10
replace BEA14Name = "Prof.Srv." if secbea14==11
replace BEA14Name = "Ed/Hlth" if secbea14==12
replace BEA14Name = "Art" if secbea14==13
replace BEA14Name = "Oth.Srv." if secbea14==14






**********************************************************
* Merge with BLS employment data by BEA industry
**********************************************************

keep if keycat66==1
replace BEA66 = 9999 if BEA66==.
merge 1:1 BEA66 quarter using tfile_bea66_employment_quarterly.dta, generate(merge0)
label var emp "Employment (CES, establishment-based, Employment Situation News Release)"
label var BEACode "BEA Official Industry Code"

replace emp=1 if varlab=="Farms"
replace BEACode="111CA" if varlab=="Farms"

//sort secbea14
//browse emp output secbea14 BEA_line keycat66 varlab BEA14Name if tin(2019q1,2019q1)









******************
* Calculate Industry TFP
******************
gen ri_share=ri/output
label var ri_share "Intermediates Share"
gen VA_share=1-ri_share
label var VA_share "Value Added Share"
egen avg_VA_share= mean(VA_share), by(BEA_line)
label var avg_VA_share "Mean Value Added Share by Industry"


gen log_tfp	= log(output) - avg_VA_share * log(emp) - (1 - avg_VA_share) * log(ri)

sort varlabi quarter
gen dlog_tfp = log_tfp - L.log_tfp

gen tfp = .
replace tfp = 1 if tin(2005q1,2005q1)
replace tfp = tfp[_n-1]*exp(dlog_tfp[_n]) if tin(2005q2,2022q2)

drop log_tfp dlog_tfp
label var tfp "TFP Index, authors calculations (2005q1=1)"






if $compare_with_bls_tfp == 1 {

preserve

gen Year = yofd(dofq(quarter))


keep BEACode quarter Year tfp output nominaloutput emp ri
collapse (mean) tfp output nominaloutput emp ri, by(Year BEACode)
label var nominaloutput "Gross Output by Industry, bn$"
label var output "Real Gross Output by Industry, 2012$bn"
label var emp "Employment"
label var ri "Real Intermediates"
label var tfp "TFP (FGI)"
rename tfp tfp_fgi
keep if Year>=2005 & Year<2022

merge m:m BEACode Year using "tfile_productivity_naics_bea66.dta"
keep if Year>=2005 & Year<2022

gen Industry_small = substr(Industry,1,10) + "_" + BEACode

encode Industry_small, gen(BEACodei)
xtset BEACodei Year
gen dtfp_fgi = 100*((tfp_fgi+L1.tfp_fgi) / (L2.tfp_fgi+L3.tfp_fgi) - 1)/2
gen dtfp_bls = 100*((BLS_TFP+L1.BLS_TFP) / (L2.BLS_TFP+L3.BLS_TFP) - 1)/2

//scatter dtfp_fgi dtfp_bls if Year==2021 & NAICS~="481", xsc(r(-20 30)) ysc(r(-20 30))
//scatter nominaloutput BLS_SO if Year==2021, xsc(r(-20 30)) ysc(r(-20 30))

gen ratio = nominaloutput/BLS_SO

list BEACode BEACodei ratio if (abs(ratio)<0.7 | abs(ratio)>1.5) & Year==2021

sum dtfp_fgi dtfp_bls if Year==2021


/// scatter dtfp_fgi dtfp_bls if Year==2021, mlabel(Industry_small)
corr dtfp_fgi dtfp_bls if Year==2021

//xtline dtfp_fgi dtfp_bls if BEACodei<=16 & tin(2015,2021), ///
//byopts(rescale) ylabel(, axis(1) angle(horizontal)) ///
//tlabel(2015 2019 2021) ///

restore

}






***********************************************************
/// Goal: to save average growth in prices, employment, output, tfp for the industries in 2020-2021 vis-a-vis 2005-2019 average
***********************************************************
/// t=8
/// z=2
/// w=4

foreach v of varlist emp output price tfp ri {

local varlabel : var label `v'

gen l`v' = log(`v')
regress D.l`v' i.varlabi if tin(2005q1,2019q4)
predict Dl`v'res if tin(2005q1,2022q2), resid
bysort varlabi (quarter) : gen l`v'res = sum(Dl`v'res) if Dl`v'res~=.
gen d`v'8 = 100*(l`v'res - L8.l`v'res)
gen d`v'2 = 100*(l`v'res - L2.l`v'res)
gen d`v'4 = 100*(l`v'res - L4.l`v'res) 
gen L4d`v'4 = L4.d`v'4
gen d`v'5 = 100*(l`v'res - L5.l`v'res) 
gen L3d`v'5 = L3.d`v'5

label variable Dl`v' "D Log of `varlabel'"
label variable l`v' "Log of `varlabel'"
label variable l`v'res "Surprise of `varlabel' relative to pre-2019 trend"
label variable d`v'8 "8-qtr Change of log `varlabel' relative to pre-2019 trend"
label variable d`v'2 "2-qtr Change of log `varlabel' relative to pre-2019 trend"
label variable d`v'4 "4-qtr Change of log `varlabel' relative to pre-2019 trend"
label variable L4d`v'4 "4-qtr lagged 4-qtr Change of log `varlabel' relative to pre-2019 trend"
label variable d`v'5 "5-qtr Change of log `varlabel' relative to pre-2019 trend"
label variable L3d`v'5 "3-qtr lagged 4-qtr Change of log `varlabel' relative to pre-2019 trend"

} 


format d* %5.2f
format L4d* %5.2f
format share %5.2f


//scatter L4dprice4 dprice8 if tin(2021q4,2021q4), mlabel(varlab_small)










sort quarter BEA_line 
by quarter: gen kk = _n if tin(2021q4,2022q4)
label var kk "Numeric Order of 66 Industries when sorted by BEA Tables"


forvalues yy = 2000(1)2022 {
forvalues qq = 1(1)4 {

by quarter: replace kk = _n if tin(`yy'q`qq',`yy'q`qq')

}
}




order kk

sort varlab_small_nonum
replace varlab_small_nonum = "Forestry" if kk==2
replace varlab_small_nonum = "Mining" if kk==4
replace varlab_small_nonum = "Oil and Gas" if kk==3
replace varlab_small_nonum = "Supp. Mining" if kk==5
replace varlab_small_nonum = "Wood" if kk==8
replace varlab_small_nonum = "Minerals" if kk==9
replace varlab_small_nonum = "Metals" if kk==11
replace varlab_small_nonum = "Computers" if kk==13
replace varlab_small_nonum = "Electr.Eqm." if kk==14
replace varlab_small_nonum = "Motor Vehicles" if kk==15
replace varlab_small_nonum = "Trans.Equip.oth." if kk==16
replace varlab_small_nonum = "Furniture" if kk==17
replace varlab_small_nonum = "Misc.Manuf." if kk==18
replace varlab_small_nonum = "Food" if kk==19
replace varlab_small_nonum = "Textile" if kk==20
replace varlab_small_nonum = "Apparel" if kk==21
replace varlab_small_nonum = "Printing" if kk==23
replace varlab_small_nonum = "Petrol.Coal" if kk==24
replace varlab_small_nonum = "Plastics" if kk==26
replace varlab_small_nonum = "Whls.Trade" if kk==27
replace varlab_small_nonum = "MV Dealers" if kk==28
replace varlab_small_nonum = "Stores Food" if kk==29
replace varlab_small_nonum = "Merch.Stores" if kk==30
replace varlab_small_nonum = "Other Retail" if kk==31
replace varlab_small_nonum = "Air Trans." if kk==32
replace varlab_small_nonum = "Water Trans." if kk==34
replace varlab_small_nonum = "Truck" if kk==35
replace varlab_small_nonum = "Ground Trans." if kk==36
replace varlab_small_nonum = "Pipeline Trans." if kk==37
replace varlab_small_nonum = "Other Trans." if kk==38
replace varlab_small_nonum = "Warehousing" if kk==39
replace varlab_small_nonum = "Software" if kk==40
replace varlab_small_nonum = "Movies" if kk==41
replace varlab_small_nonum = "Broadcasting" if kk==42
replace varlab_small_nonum = "Data Process" if kk==43
replace varlab_small_nonum = "Banks" if kk==44
replace varlab_small_nonum = "Securities" if kk==45
replace varlab_small_nonum = "Insurers" if kk==46
replace varlab_small_nonum = "Funds" if kk==47
replace varlab_small_nonum = "Leasing" if kk==50
replace varlab_small_nonum = "Comp.Systems" if kk==52
replace varlab_small_nonum = "Miscell.Services" if kk==53
replace varlab_small_nonum = "Mgt.Companies" if kk==54
replace varlab_small_nonum = "Admin.Services" if kk==55
replace varlab_small_nonum = "Waste" if kk==56
replace varlab_small_nonum = "Education" if kk==57
replace varlab_small_nonum = "Nursing" if kk==60
replace varlab_small_nonum = "Arts,Sports" if kk==62
replace varlab_small_nonum = "Gambling" if kk==63
replace varlab_small_nonum = "Restaurants" if kk==65
replace varlab_small_nonum = "Other Services" if kk==66
















************
* MERGE WITH CONSUMPTION DATA
***********
merge m:1 BEACode using tfile_goods_share.dta, generate(merge_123)
replace tot_spend_good = 0 if tot_spend_good ==.
replace tot_spend_serv = 0 if tot_spend_serv ==.
label var tot_spend_good "Total Spending Goods from Bridge Data"
label var tot_spend_serv "Total Spending Services from Bridge Data"

egen mri_share = mean(ri_share), by(kk)
label var mri_share "Mean Intermediates Share by Industry"
format mri_share %5.2f


********************
* Table A.1 (PROPER TABLE NEEDS TO BE FORMATTED WITH EXCEL TO HAVE DECIMALS FOR A NUMBER LIKE 20,000)
********************
sort BEA_line
order BEACode BEAName share tot_spend_good tot_spend_serv 
//browse BEACode BEAName share tot_spend_good tot_spend_serv if tin(2019q4,2019q4) 
listtex BEACode BEAName share tot_spend_good tot_spend_serv if tin(2019q4,2019q4) using charts/Table_A1.tex, rstyle(tabular) replace





gen industry_model = "Other" 
label var industry_model "Industry: Goods or Services or Other"

replace industry_model = "Goods" if tot_spend_good>tot_spend_serv & tot_spend_good>0
replace industry_model = "Services" if tot_spend_good<=tot_spend_serv & tot_spend_serv>0

 






******************
* EXPORT TO EXCEL 66 INDUSTRIES FOR 2021Q4, 8 quarters
******************

* Adjust TFP using Fernald's TFP trend

egen mean_dtfp8 = sum(dtfp8*share/100) if share~=. & dtfp8~=., by(quarter)
egen mean_dtfp2 = sum(dtfp2*share/100) if share~=. & dtfp2~=., by(quarter)


sort varlabi quarter
gen double LTFPM = 0 if tin(2005q1,2005q1)
bysort varlabi (quarter) : replace LTFPM = L.LTFPM + TFPMQ/400 if tin(2005q2,2022q4)
regress D.LTFPM if tin(2005q1,2019q4) 
predict DLTFPMres, resid
bysort varlabi (quarter) : gen LTFPMres = sum(DLTFPMres)


gen dtfp8_fernald_ua = 100*(LTFPMres - L8.LTFPMres)
gen dtfp2_fernald_ua = 100*(LTFPMres - L2.LTFPMres)


label var mean_dtfp8 "Weighted Avg.TFP Matt, 8-qtr %chg, relative to 2005-2019 trend"
label var dtfp8_fernald_ua "TFP ua Fernald, 8-qtr %chg, relative to 2005-2019 trend"

format mean_dtfp8 dtfp8_fernald_ua   %5.2f
list quarter mean_dtfp8 dtfp8_fernald_ua if kk==1 & tin(2005q1,2022q4), abb(20)



* Export surprises in variables relative to pre-pandemic trend between 2021q4 and 2019q4

preserve

keep if tin(2021q4,2021q4)

sort kk
replace dtfp8 = dtfp8 - mean_dtfp8 + dtfp8_fernald_ua

order kk BEA_line BEACode BEAName varlab_small_nonum ///
dtfp8 dprice8 doutput8 demp8 dri8 ///
share industry_model tot_spend_good tot_spend_serv mri_share L4dprice4

keep kk BEA_line BEACode BEAName varlab_small_nonum ///
dtfp8 dprice8 doutput8 demp8 dri8 ///
share industry_model tot_spend_good tot_spend_serv mri_share L4dprice4

export excel using "Stata_to_excel_all_industries.xls", sheetreplace firstrow(variables)

restore










******************
* EXPORT TO EXCEL 66 INDUSTRIES FOR 2022Q2, 2 quarters
******************

preserve

* Export surprises in variables relative to pre-pandemic trend between 2022q2 and 2021q4
keep if tin(2022q2,2022q2)

sort kk
replace dtfp2 = dtfp2 - mean_dtfp2 + dtfp2_fernald_ua

order kk BEA_line BEACode BEAName varlab_small_nonum ///
dtfp2 dprice2 doutput2 demp2 dri2 ///
share industry_model tot_spend_good tot_spend_serv mri_share 

keep kk BEA_line BEACode BEAName varlab_small_nonum ///
dtfp2 dprice2 doutput2 demp2 dri2 ///
share industry_model tot_spend_good tot_spend_serv mri_share 

export excel using "Stata_to_excel_all_industries_2022Q2.xls", sheetreplace firstrow(variables)

restore




















******************
* EXPORT TO EXCEL 14 INDUSTRIES
******************
preserve 

keep if tin(2021q4,2021q4)
sort kk

egen W_output = sum(output), by(secbea14)
egen W_emp = sum(emp), by(secbea14)
gen s_output = output/W_output
gen s_emp = emp/W_emp

gen dtfp8_w = s_output*dtfp8
gen dprice8_w = s_output*dprice8
gen demp8_w = s_output*demp8
gen dri8_w = s_output*dri8
gen doutput8_w = s_output*doutput8
gen alpha_w = s_output*mri_share

format dtfp8_w dprice8_w demp8_w doutput8_w dri8_w mri_share %5.2f

replace varlab_small_nonum = BEA14Name
replace dtfp8_w = dtfp8_w - mean_dtfp8 + dtfp8_fernald_ua


collapse ///
(firstnm) BEA14Name industry_model BEA_line BEACode BEAName varlab_small_nonum  ///
(sum) dtfp8_w dprice8_w demp8_w doutput8_w dri8_w ///
(sum) tot_spend_good tot_spend_serv share alpha_w, by(secbea14)

order secbea14 BEA_line BEACode BEA14Name varlab_small_nonum ///
dtfp8_w dprice8_w doutput8_w demp8_w dri8_w ///
share industry_model tot_spend_good tot_spend_serv alpha_w

keep secbea14 BEA_line BEACode BEA14Name varlab_small_nonum ///
dtfp8_w dprice8_w doutput8_w demp8_w dri8_w ///
share industry_model tot_spend_good tot_spend_serv alpha_w
export excel using "Stata_to_excel_few_industries.xls", sheetreplace firstrow(variables)

restore

* https://apps.bea.gov/iTable/iTable.cfm?reqid=150&step=3&isuri=1&table_list=6019&categories=makeuse



























*********************************************************
* CHARTS HERE
*********************************************************

global t1_trend="2005q1"
global t2_trend="2019q4"

global t1_index="2010q1"
global t2_index="2019q4"

global t1_plot="2010q1"
global t2_plot="2022q2"
global t2_plotm="2022m6"




sort varlabi quarter
gen DP4 = 100*(JC/L4.JC-1)
gen DP4_G = 100*(JCTG/L4.JCTG-1)
gen DP4_S = 100*(JCS/L4.JCS-1)

format PCE* DP4* %5.2f


sort industry_model quarter 


egen totoutputi = sum(output), by(industry_model quarter)
gen sharei = output/totoutputi



sort varlabi quarter


foreach v of varlist output emp price tfp ri {

* This bit here to remove linear industry trend period below
regress l`v' i.kk i.kk#c.quarter if tin($t1_trend,$t2_trend)
predict l`v'resx, resid
gen `v'res = 100*exp(l`v'resx)

* This bit here to index to 100 in period below
regress `v'res i.kk if tin($t1_index,$t2_index)
predict `v'res2, resid
replace `v'res = `v'res2+100
drop `v'res2
}



foreach v of varlist ///
outputres empres priceres tfpres rires dtfp8 dtfp2 {

egen wmean`v' = sum(`v'*sharei) if `v'~=., by(industry_model quarter)
egen mean`v' = mean(`v') if `v'~=., by(industry_model quarter)

separate `v' if `v'~=., by(industry_model)
separate mean`v' if `v'~=., by(industry_model)
separate wmean`v' if `v'~=., by(industry_model)

}

sort varlabi quarter



















**************************************************
* FIGURE 2: CROSS-SECTIONAL COVID DYNAMICS (3 PDF)
**************************************************


* PART 1

twoway ///
(line outputres1 outputres3 outputres2 wmeanoutputres1 wmeanoutputres3 quarter if tin($t1_plot,$t2_plot), ///
c(L L L L L) ///
lw(medium medium thin medthick medthick) ///
tlabel($t1_plot 2015q1 2019q4 2021q4) ///
xtitle("") ///
ysc(r(40 200)) ///
ylabel(40(30)200, axis(1) angle(horizontal)) ///
ylabel(40(30)200, axis(2) angle(horizontal)) ///
yaxis(1 2) ///
ytitle("Indexes (2010-2019=100)") ///
title("Real Gross Output", size(medium)) ///
ylabel(, labcolor(black) angle(horizontal) format(%5.0f)) ///
legend(size(*.7) ring(0) symysize(*0.01) symxsize(*0.4) position(11) ///
rows(3) order(4 "Goods Industries Avg." ///
5 "Services Industries Avg." ///
1 "Goods Industries" ///
2 "Services Industries" ///
3 "Other Industries")) ///
lcolor(blue*0.3 red*0.3 gray*0.5 blue red)), ///
name(outputres_cs, replace) graphregion(fcolor(white)) 

graph display, ysize(2) xsize(5)  scale(1.5)
graph export charts/outputres_cs.pdf, name(outputres_cs) replace logo(off) mag(100) 




* PART 2

twoway ///
(line priceres1 priceres3 priceres2 wmeanpriceres1 wmeanpriceres3 quarter if tin($t1_plot,$t2_plot), ///
c(L L L L L) ///
lw(medium medium thin medthick medthick) ///
tlabel($t1_plot 2015q1 2019q4 2021q4) ///
xtitle("") ///
ysc(r(40 240)) ///
ylabel(40(30)210, axis(1) angle(horizontal)) ///
ylabel(40(30)210, axis(2) angle(horizontal)) ///
yaxis(1 2) ///
ytitle("Indexes (2010-2019=100)") ///
title("Prices", size(medium)) ///
ylabel(, labcolor(black) angle(horizontal) format(%5.0f)) ///
legend(size(*.7) ring(0) symysize(*0.01) symxsize(*0.4) position(11) ///
rows(3) order(4 "Goods Industries Avg." ///
5 "Services Industries Avg." ///
1 "Goods Industries" ///
2 "Services Industries" ///
3 "Other Industries")) ///
lcolor(blue*0.3 red*0.3 gray*0.5 blue red)), ///
name(priceres_cs, replace) graphregion(fcolor(white)) 

graph display, ysize(2) xsize(5)  scale(1.5)
graph export charts/priceres_cs.pdf, name(priceres_cs) replace logo(off) mag(100) 





* PART 3


twoway ///
(line empres1 empres3 empres2 wmeanempres1 wmeanempres3 quarter if tin($t1_plot,$t2_plot), ///
c(L L L L L) ///
lw(medium medium thin medthick medthick) ///
tlabel($t1_plot 2015q1 2019q4 2021q4) ///
xtitle("") ///
ysc(r(40 150)) ///
ylabel(40(20)140, axis(1) angle(horizontal)) ///
ylabel(40(20)140, axis(2) angle(horizontal)) ///
yaxis(1 2) ///
ytitle("Indexes (2010-2019=100)") ///
title("Employment", size(medium)) ///
ylabel(, labcolor(black) angle(horizontal) format(%5.0f)) ///
legend(size(*.7) ring(0) symysize(*0.01) symxsize(*0.4) position(7) ///
rows(3) order(4 "Goods Industries Avg." ///
5 "Services Industries Avg." ///
1 "Goods Industries" ///
2 "Services Industries" ///
3 "Other Industries")) ///
lcolor(blue*0.3 red*0.3 gray*0.5 blue red)), ///
name(empres_cs, replace) graphregion(fcolor(white)) 

graph display, ysize(2) xsize(5)  scale(1.5)
graph export charts/empres_cs.pdf, name(empres_cs) replace logo(off) mag(100) 


































**************************************************
* FIGURE 1: AGGREGATE COVID DYNAMICS (3 PDF)
**************************************************

format PCE* DP4* %5.2f

egen NTOT = sum(emp), by(quarter)
egen NTOTG = sum(emp) if industry_model=="Goods", by(quarter)
egen NTOTS = sum(emp) if industry_model=="Services", by(quarter)
egen NTOTG0 = mean(NTOTG), by(quarter)
replace NTOTG = NTOTG0
egen NTOTS0 = mean(NTOTS), by(quarter)
replace NTOTS = NTOTS0



foreach v of varlist NTOT NTOTG NTOTS CSH CTGH CH {
gen l`v' = log(`v')
reg l`v' quarter if tin(2005q1,2019q4)
predict l`v'TREND, xb
gen `v'TREND = exp(l`v'TREND)
sum `v'TREND if tin(2019q4,2019q4)
gen `v'TREND100 = `v'TREND/`r(mean)'*100
sum `v' if tin(2019q4,2019q4)
gen `v'100 = `v'/`r(mean)'*100
replace `v'TREND100 = . if tin(1985q1,2019q3)
gen `v'DETRENDED = 100*(`v'100/`v'TREND100)
}

gen CSHAREGN = CTG/C*100
gen CSHAREGR = CTGH/CH*100





* PART 1

twoway ///
(tsline CH100 CTGH100 CSH100 if tin($t1_plot,$t2_plot), ///
lcolor(black blue red) lw(.5 .4 .4) ytitle("") ///
xtitle("") ///
yaxis(1 2) ///
ylabel(70(10)125, axis(1) angle(horizontal) format(%5.0f)) ///
ylabel(70(10)125, axis(2) angle(horizontal) format(%5.0f)) ///
tlabel($t1_plot 2015q1 2019q4 2021q4) ///
ytitle("Index (2019q4=100)") ///
title("Real Consumption Expenditures", size(medium)) ///
legend(size(*.8) ring(0) symysize(*0.01) symxsize(*0.4) position(11) rows(3) ///
order(1 "Consumption (Total)" 2 "Consumption Goods" 3 "Consumption Services"))), ///
name(ctot_agg, replace) graphregion(fcolor(white)) 

graph display, ysize(1.65) xsize(3)  scale(1.70)

graph export charts/ctot_agg.pdf, name(ctot_agg) replace logo(off) mag(100) 








* PART 2

preserve

import delimited "Consumption_monthly.csv", encoding(ISO-8859-2) clear
format date 

gen M = substr(date,6,2)
gen year = substr(date,1,4)

destring M year, replace
gen edate = mdy(M,1,year)
gen month = mofd(edate)
drop M edate
format month %tm

gen goodshare = 100*(1 - csbm/cbm)
tsset month


twoway ///
(tsline goodshare if tin(1960m1,$t2_plotm), ///
lcolor(blue) lw(.5) ytitle("") ///
xtitle("") ///
yaxis(1 2) ///
ylabel(31(4)35 40 45 50, axis(1) angle(horizontal) format(%5.0f)) ///
ylabel(31(4)35 40 45 50, axis(2) angle(horizontal) format(%5.0f)) ///
tlabel(1960m1 1980m1 2000m1 2019m12) ///
ytitle("Percent") ///
ytitle("", axis(2)) ///
title("Goods Consumption Expenditure Share", size(medium))), ///
name(ctot_share_1960m, replace) graphregion(fcolor(white))

graph display, ysize(1.65) xsize(3)  scale(1.70)

graph export charts/ctot_share_1960m.pdf, name(ctot_share_1960m) replace logo(off) mag(100) 

list month goodshare


restore




















* PART 3

twoway ///
(tsline DP4 DP4_G DP4_S if tin($t1_plot,$t2_plot), ///
lcolor(black blue red) lw(.5 .4 .4) ytitle("") ///
xtitle("") ///
yaxis(1 2) ///
ylabel(-2(2)10, axis(1) angle(horizontal) format(%5.0f)) ///
ylabel(-2(2)10, axis(2) angle(horizontal) format(%5.0f)) ///
tlabel($t1_plot 2015q1 2019q4 2021q4) ///
ytitle("Percent, Year-on-year changes") ///
title("Inflation", size(medium)) ///
legend(size(*.8) ring(0) symysize(*0.01) symxsize(*0.4) position(11) rows(3) ///
order(1 "Inflation (Total)" 2 "Inflation Goods" 3 "Inflation Services"))), ///
///
name(dptot_agg, replace) graphregion(fcolor(white)) 

graph display, ysize(1.65) xsize(3)  scale(1.70)
graph export charts/dptot_agg.pdf, name(dptot_agg) replace logo(off) mag(100) 










* PART 4

twoway ///
(tsline NTOT100 NTOTG100 NTOTS100 if tin($t1_plot,$t2_plot), ///
lcolor(black blue red) lw(.5 .4 .4) ytitle("") ///
xtitle("") ///
yaxis(1 2) ///
ylabel(85(5)105, axis(1) angle(horizontal) format(%5.0f)) ///
ylabel(85(5)105, axis(2) angle(horizontal) format(%5.0f)) ///
tlabel($t1_plot 2015q1 2019q4 2021q4) ///
title("Employment", size(medium)) ///
ytitle("Index (2019q4=100)") ///
legend(size(*.8) ring(0) symysize(*0.01) symxsize(*0.4) position(11) rows(3) ///
order(1 "Employment (Total)" 2 "Employment Goods" 3 "Employment Services"))), ///
///
name(emptot_agg, replace) graphregion(fcolor(white)) 

graph display, ysize(1.65) xsize(3)  scale(1.70)
graph export charts/emptot_agg.pdf, name(emptot_agg) replace logo(off) mag(100) 










* PART 1 FOR SLIDES ONLY

twoway ///
(tsline CH100 CTGH100 CSH100 if tin($t1_plot,$t2_plot), ///
lcolor(black blue red) lw(.5 .4 .4) ytitle("") ///
xtitle("") ///
yaxis(1 2) ///
ylabel(70(10)125, axis(1) angle(horizontal) format(%5.0f)) ///
ylabel(70(10)125, axis(2) angle(horizontal) format(%5.0f)) ///
tlabel($t1_plot 2015q1 2018q1 2021q4) ///
ytitle("Index (2019q4=100)") ///
title("Real Consumption Expenditures", size(medium)) ///
legend(size(*.8) ring(0) symysize(*0.01) symxsize(*0.4) position(11) rows(3) ///
order(1 "Consumption (Total)" 2 "Consumption Goods" 3 "Consumption Services"))), ///
///
name(zoom2, replace) graphregion(fcolor(white)) 
graph display, ysize(2) xsize(2)  scale(1.6)


twoway ///
(tsline CSHAREGN if tin($t1_plot,$t2_plot), lcolor(blue) lwidth(.5)  ///
tlabel($t1_plot 2015q1 2018q1 2021q4) ///
yaxis(1 2) ///
ytitle("Percent") ///
ylabel(31(1)35, axis(1) angle(horizontal) format(%5.0f)) ///
ylabel(31(1)35, axis(2) angle(horizontal) format(%5.0f)) ///
xtitle("") ///
ytitle("", axis(2)) ///
title("Goods Nominal Share", size(medium)) ), ///
name(small2, replace) 
graph display, ysize(2) xsize(2)  scale(1.6)

graph close zoom2
graph close small2
graph combine zoom2 small2, name(c_agg_slides, replace) ysize(1.5) xsize(3.3)  scale(1.05)
graph export charts/c_agg_slides.pdf, name(c_agg_slides) replace logo(off) mag(100) 
















egen sdp = sd(dprice8), by(quarter)
egen sdl = sd(demp8), by(quarter)
egen sdy = sd(doutput8), by(quarter)
egen sda = sd(dtfp8), by(quarter)
egen sdi = sd(dri8), by(quarter)

format CH* CSH* NTOT* sd* %5.2f 
list quarter DP4* CSHAREGN NTOT100 CH100 sda sdl sdp sdy sdi if kk==1 & (tin(2019q4,2019q4) | tin(2021q4,2021q4))

list quarter DP4* CSHAREGN NTOT100 CH100 sda sdl sdp sdy sdi if kk==1 & (tin(2007q4,2007q4) | tin(2009q4,2009q4))





*******************************************************
* SOME AGGREGATE STATISTICS 
*******************************************************


format CH* CSH* NTOT* CT* sd* %5.2f 

foreach v of varlist NTOT NTOTG NTOTS CSH CTGH CH {
list quarter `v'100 `v'TREND100 `v'DETRENDED if kk==1 & tin(2019q4,2021q4)
sum `v'100 `v'TREND100 `v'DETRENDED if kk==1 & tin(2019q4,2021q4)
}











**********************************************************************
* MONTHLY CONSUMPTION CHARTS
**********************************************************************

//cdbm: Personal Consumption Expenditures: Durable Goods, Billions of Dollars, Monthly, Seasonally Adjusted Annual Rate		
//cbm: 	Personal Consumption Expenditures, Billions of Dollars, Monthly, Seasonally Adjusted Annual Rate		
//csbm: Personal Consumption Expenditures: Services, Billions of Dollars, Monthly, Seasonally Adjusted Annual Rate		
//cnbm: Personal Consumption Expenditures: Nondurable Goods, Billions of Dollars, Monthly, Seasonally Adjusted Annual Rate		

preserve

import delimited "Consumption_monthly.csv", encoding(ISO-8859-2) clear

gen M = substr(date,6,2)
gen year = substr(date,1,4)
destring M year, replace
gen edate = mdy(M,1,year)
gen month = mofd(edate)
drop M edate
format month %tm

gen goodshare = 100*(1 - csbm/cbm)

tsset month

twoway line goodshare month if tin(2002m1,2022m6), ///
tlabel(2002m1 2008m1 2015m1 2019m12 2021m12, labsize(small)) ///
yaxis(1 2) ///
ylabel(31(1)36, axis(1) angle(horizontal) format(%5.0f)) ///
ylabel(31(1)36, axis(2) angle(horizontal) format(%5.0f)) ///
lw(medthick)  xtitle("") ///
ytitle("", axis(2)) ///
ytitle("Percent") lcolor(blue) name(csharem, replace)

graph display, ysize(2) xsize(5)  scale(1.5)
graph export charts/monthly_share.pdf, name(csharem) replace logo(off) mag(100) 

restore











**********************************************
* TABLES A.2
**********************************************

import excel Stata_to_excel_all_industries.xls, firstrow clear
listtex BEACode BEAName share dprice8 doutput8 demp8 dtfp8 using charts/Table_A2.tex, rstyle(tabular) replace
order BEACode BEAName share dprice8 doutput8 demp8 dtfp8 
//browse BEACode BEAName share dprice8 doutput8 demp8 dtfp8 



**********************************************
* TABLES A.3 for 2022
**********************************************
import excel Stata_to_excel_all_industries_2022Q2.xls, firstrow clear
listtex BEACode BEAName share dprice2 doutput2 demp2 dtfp2 using charts/Table_A2_2022.tex, rstyle(tabular) replace
order  BEACode BEAName share dprice2 doutput2 demp2 dtfp2 
//browse BEACode BEAName share dprice2 doutput2 demp2 dtfp2 






/*




































// sum DP4 DP4_G DP4_S if tin(1990q1,2019q4)
// list quarter DP4_G DP4_S if  tin(2018q1,2021q4) & BEA66==1



// Memorandum

/// 66 Industries FOR MATLAB
/*
. list kk varlab_original  if kk<=66 & tin(2019q1,2019q1), noobs sep(100)

  +-----------------------------------------------------------------------------------------+
  | kk   BEA66                                                              varlab_original |
  |-----------------------------------------------------------------------------------------|
  | 64       1                                                                Accommodation |
  | 55       2                                          Administrative and support services |
  | 32       3                                                           Air transportation |
  | 58       4                                              Ambulatory health care services |
  | 63       5                              Amusements, gambling, and recreation industries |
  | 21       6                                      Apparel and leather and allied products |
  | 42       7                                          Broadcasting and telecommunications |
  | 25       8                                                            Chemical products |
  | 13       9                                             Computer and electronic products |
  | 52      10                                 Computer systems design and related services |
  |  7      11                                                                 Construction |
  | 43      12         Data processing, internet publishing, and other information services |
  | 57      13                                                         Educational services |
  | 14      14                             Electrical equipment, appliances, and components |
  | 11      15                                                    Fabricated metal products |
  |  1      16                                                                        Farms |
  | 44      17         Federal Reserve banks, credit intermediation, and related activities |
  | 19      18                                       Food and beverage and tobacco products |
  | 29      19                                                     Food and beverage stores |
  | 65      20                                            Food services and drinking places |
  |  2      21                                    Forestry, fishing, and related activities |
  | 47      22                                  Funds, trusts, and other financial vehicles |
  | 17      23                                               Furniture and related products |
  | 30      24                                                   General merchandise stores |
  | 59      25                                                                    Hospitals |
  | 48      26                                                                      Housing |
  | 46      27                                    Insurance carriers and related activities |
  | 51      28                                                               Legal services |
  | 12      29                                                                    Machinery |
  | 54      30                                      Management of companies and enterprises |
  |  4      31                                                   Mining, except oil and gas |
  | 18      32                                                  Miscellaneous manufacturing |
  | 53      33               Miscellaneous professional, scientific, and technical services |
  | 41      34                                Motion picture and sound recording industries |
  | 28      35                                              Motor vehicle and parts dealers |
  | 15      36                               Motor vehicles, bodies and trailers, and parts |
  |  9      37                                                 Nonmetallic mineral products |
  | 60      38                                      Nursing and residential care facilities |
  |  3      39                                                       Oil and gas extraction |
  | 49      40                                                            Other real estate |
  | 31      41                                                                 Other retail |
  | 66      42                                            Other services, except government |
  | 38      43                                  Other transportation and support activities |
  | 16      44                                               Other transportation equipment |
  | 22      45                                                               Paper products |
  | 62      46           Performing arts, spectator sports, museums, and related activities |
  | 24      47                                                  Petroleum and coal products |
  | 37      48                                                      Pipeline transportation |
  | 26      49                                                 Plastics and rubber products |
  | 10      50                                                               Primary metals |
  | 23      51                                      Printing and related support activities |
  | 40      52                   Publishing industries, except internet (includes software) |
  | 33      53                                                          Rail transportation |
  | 50      54                 Rental and leasing services and lessors of intangible assets |
  | 45      55                             Securities, commodity contracts, and investments |
  | 61      56                                                            Social assistance |
  |  5      57                                                Support activities for mining |
  | 20      58                                      Textile mills and textile product mills |
  | 36      59                                  Transit and ground passenger transportation |
  | 35      60                                                         Truck transportation |
  |  6      61                                                                    Utilities |
  | 39      62                                                      Warehousing and storage |
  | 56      63                                    Waste management and remediation services |
  | 34      64                                                         Water transportation |
  | 27      65                                                              Wholesale trade |
  |  8      66                                                                Wood products |
  +-----------------------------------------------------------------------------------------+
/*




/// LIST AS PER BEA TABLES
/*
1	    Gross domestic product
2	Private industries
3	  Agriculture, forestry, fishing, and hunting
4	    Farms
5	    Forestry, fishing, and related activities
6	  Mining
7	    Oil and gas extraction
8	    Mining, except oil and gas
9	    Support activities for mining
10	  Utilities
11	  Construction
12	  Manufacturing
13	    Durable goods
14	      Wood products
15	      Nonmetallic mineral products
16	      Primary metals
17	      Fabricated metal products
18	      Machinery
19	      Computer and electronic products
20	      Electrical equipment, appliances, and components
21	      Motor vehicles, bodies and trailers, and parts
22	      Other transportation equipment
23	      Furniture and related products
24	      Miscellaneous manufacturing
25	    Nondurable goods
26	      Food and beverage and tobacco products
27	      Textile mills and textile product mills
28	      Apparel and leather and allied products
29	      Paper products
30	      Printing and related support activities
31	      Petroleum and coal products
32	      Chemical products
33	      Plastics and rubber products
34	  Wholesale trade
35	  Retail trade
36	    Motor vehicle and parts dealers
37	    Food and beverage stores
38	    General merchandise stores
39	    Other retail
40	  Transportation and warehousing
41	    Air transportation
42	    Rail transportation
43	    Water transportation
44	    Truck transportation
45	    Transit and ground passenger transportation
46	    Pipeline transportation
47	    Other transportation and support activities
48	    Warehousing and storage
49	  Information
50	    Publishing industries, except internet (includes software)
51	    Motion picture and sound recording industries
52	    Broadcasting and telecommunications
53	    Data processing, internet publishing, and other information services
54	  Finance, insurance, real estate, rental, and leasing
55	    Finance and insurance
56	      Federal Reserve banks, credit intermediation, and related activities
57	      Securities, commodity contracts, and investments
58	      Insurance carriers and related activities
59	      Funds, trusts, and other financial vehicles
60	    Real estate and rental and leasing
61	      Real estate
62	        Housing
63	        Other real estate
64	      Rental and leasing services and lessors of intangible assets
65	  Professional and business services
66	    Professional, scientific, and technical services
67	      Legal services
68	      Computer systems design and related services
69	      Miscellaneous professional, scientific, and technical services
70	    Management of companies and enterprises
71	    Administrative and waste management services
72	      Administrative and support services
73	      Waste management and remediation services
74	  Educational services, health care, and social assistance
75	    Educational services
76	    Health care and social assistance
77	      Ambulatory health care services
78	      Hospitals
79	      Nursing and residential care facilities
80	      Social assistance
81	  Arts, entertainment, recreation, accommodation, and food services
82	    Arts, entertainment, and recreation
83	      Performing arts, spectator sports, museums, and related activities
84	      Amusements, gambling, and recreation industries
85	    Accommodation and food services
86	      Accommodation
87	      Food services and drinking places
88	  Other services, except government
89	Government
90	  Federal
91	    General government
92	      National defense
93	      Nondefense
94	    Government enterprises
95	  State and local
96	    General government
97	    Government enterprises
98	  Not allocated by industry\1\
	  Addenda:
99	      Private goods-producing industries\2\
100	      Private services-producing industries\3\
101	      Information-communications-technology-producing industries\ 4\

*/

